@@ -63,6 +63,7 @@ sub run_update {
   Bio::Otter::Lace::Defaults::do_getopt();
   my $cl          = Bio::Otter::Lace::Defaults::make_Client();
   my $dataset     = $cl->get_DataSet_by_name($dataset_name);
+  print "Dataset: $dataset\n" if($VERBOSE);
   my $loutre_dba  = $dataset->get_cached_DBAdaptor;
   my $slice_Ad    = $loutre_dba->get_SliceAdaptor;
   my $gene_Ad     = $loutre_dba->get_GeneAdaptor;
@@ -70,10 +71,19 @@ sub run_update {
   my %sets;
   my $ssets = $dataset->get_all_visible_SequenceSets;
   foreach my $sset ( @$ssets ){
+    #print "chromsome: ".$sset->name."\n" if($VERBOSE);
     my ($chrom) = ($sset->name) =~ /chr(\d+|\w+)-.*/i;
     next unless $chrom;
     $sets{$chrom} = $sset->name;
   }
+  if(!scalar keys %sets){
+    foreach my $sset ( @$ssets ){
+    #print "chromsome: ".$sset->name."\n" if($VERBOSE);
+    my ($chrom) = ($sset->name) =~ /chr(\d+|\w+)_.*/i;
+    next unless $chrom;
+    $sets{$chrom} = $sset->name;
+  }
+  }
 
   my $do_prefetch_transcripts = 1;
   # Hash structured like this: $aeh->{'NCBI36'}{'11'} = 'chr11-02';
@@ -81,8 +91,9 @@ sub run_update {
 
   my @ordered_chroms = sort _sortbychrnum keys %sets;
 
+  my $c = 0;
   foreach my $chromosome (@ordered_chroms){
-    print "CHROMOSOME $chromosome\n";
+    print "CHROMOSOME $chromosome / ".$sets{$chromosome}."\n";
 
     if($test){ next unless $chromosome eq "21" }
 
@@ -90,20 +101,26 @@ sub run_update {
     my $ncbi_genes = [];
     my $hav_slice;
 
-    if($test){ $hav_slice = $slice_Ad->fetch_by_region('chromosome', $sets{$chromosome},
-					       30954891, 30985000, undef, 'Otter'); }
+    if($ENVI eq "zfish"){
+      #zfish
+      $hav_slice = $slice_Ad->fetch_by_region('chromosome', $chromosome,
+					      undef, undef, undef, "Zv9");
+      $ncbi_genes = $hav_slice->get_all_Genes(undef, undef, undef, 'havana');
+    }
     else{
       $hav_slice = $slice_Ad->fetch_by_region('chromosome', $sets{$chromosome},
-					       undef, undef, undef, 'Otter');
-    }
-    die "\nCould not get slice for ".$sets{$chromosome}."\n\n" if(!$hav_slice);
+					      undef, undef, undef, 'Otter');
 
-    $ncbi_genes = $gene_Ad->fetch_all_genes_on_reference_slice($chromosome, $sets{$chromosome},
-							       $hav_slice, $ncbi_version);
+      die "\nCould not get slice for ".$sets{$chromosome}."\n\n" if(!$hav_slice);
+      
+      $ncbi_genes = $gene_Ad->fetch_all_genes_on_reference_slice($chromosome, $sets{$chromosome},
+								 $hav_slice, $ncbi_version);
+    }
 
     foreach my $gene (@$ncbi_genes) {
       #create objects and store in AnnoTrack
       create_objects($gene, $chromosome, $prepare_hash, $tracking_dbh, $user_id, $category_id);
+      last if($test && ($c++>20));
     }
 
   }
@@ -257,7 +274,7 @@ sub create_objects {
 	my $coding_start = $exon->coding_region_start($transcript);
 	my $coding_end   = $exon->coding_region_end($transcript);
 
-	if($coding_start and $VERBOSE){ print "CONGS: ".$exon->seq_region_start." - $coding_start.\n"; }
+	#if($coding_start and $VERBOSE){ print "CONGS: ".$exon->seq_region_start." - $coding_start.\n"; }
 
 	if ( !defined $coding_start ) {
 	  #non-coding exon
