@@ -9,7 +9,7 @@ Helper script for the GENCODE tracking system, to be run nightly.
 Connect to the internal tracking system db, compare data and set flags.
 
 This script can be used to call data-specific analysis fucntions.
-Some examples are given here, they are specific for.
+Some examples are given here.
 
 Explicitely set analysis to run below.
 
@@ -56,7 +56,7 @@ my $ENSEMBL_new_cdnas = 0;
 my $HAVANA_overlaps   = 0;
 my $flagged_pseudos   = 0;
 my $MIT_CONGO         = 0;
-my $missed_ccds       = 0;
+my $missed_ccds       = 1;
 my $missed_hgnc       = 0;
 my $use_file          = 0;
 my $UCSC_retros       = 0;
@@ -121,6 +121,21 @@ my $user_id = get_user_id( $user_name, $tracking_dbh );
 
 my $prepare_hash = prepare_statements($tracking_dbh);
 
+##get sources
+#foreach my $das_source (keys %OTHER_SERVERS) {
+#  print STDERR "\n-------------------------------------\nLooking at $das_source.".
+#               "\n-------------------------------------\n";
+#  if(!($OTHER_SERVERS{$das_source}->{'active'})){
+#    print STDERR "Not active.\n";
+#    next;
+#  }
+
+#  #RUN UPDATE FUNCTIONS
+#   $function   = $OTHER_SERVERS{$das_source}->{'update_function'};
+#   $flag_count = $function($das_source, $OTHER_SERVERS{$das_source}->{'flag_name'}, 0);
+#   print STDERR "Set $flag_count new flags.\n";
+#}
+
 if($ucsc_novelloci){
   $flag_count = check_new_locus('ucsc_novelloci', 'novel_locus', 0);
   print STDERR "Set $flag_count new flags.\n";
@@ -707,3 +722,9 @@ sub set_flags_for_ids2 {
 
 __END__
 
+
+INSERT INTO `flags` VALUES (1,-1,'other_problem',0,NULL,NULL,NULL),(2,-1,'missing_exon',0,NULL,NULL,NULL),(3,-1,'missing_intron',0,NULL,NULL,NULL),(4,-1,'overlapping_cds',0,NULL,NULL,NULL),(5,-1,'different_cds',0,NULL,NULL,NULL),(6,-1,'different_splice_sites',0,NULL,NULL,NULL),(7,-1,'different_splice_start_or_end',0,NULL,NULL,NULL),(8,-1,'novel_locus',0,NULL,NULL,NULL),(9,-1,'novel_isoform',0,NULL,NULL,NULL),(10,-1,'missing_cdna',0,NULL,NULL,NULL);
+
+
+delete from flags where flag_name="missing_exon" and issue_id > 0 and checked_date is null;
+select count(*) from flags where flag_name="missing_exon" and issue_id > 0 and checked_date is null;
