@@ -1,7 +1,7 @@
-# wrapper script to be called as cron-job
-# includes system-specific locations of the perl libraries
-# Please fill in your system settings
-#
+# Annotrack wrapper script to be called as cron-job,
+# includes system-specific locations of the perl libraries.
+# Please fill in your system settings if running elsewhere.
+# Felix Kokocinski
 # fsk@sanger.ac.uk, April 2010
 
 use strict;
@@ -15,8 +15,7 @@ my $write = '-write';
 my @libs;
 my $cmd;
 
-#path to your annotrack directory
-my $annotrack_path = "/full-path/tracking_system/";
+my $annotrack_path = "/nfs/users/nfs_f/fsk/1_cvs/gencode/tracking_system/";
 
 ########### perl libraries ################
 
@@ -24,16 +23,16 @@ my $annotrack_path = "/full-path/tracking_system/";
 $libs[0] = $annotrack_path.'perl/modules';
 
 #Ensembl API modules
-$libs[1] = '/full-path/ensembl/modules';
+$libs[1] = '/nfs/users/nfs_f/fsk/1_cvs/ensembl/modules';
 #Bio-Perl modules
-$libs[2] = '/full-path/BioPerl-1.6.0';
+$libs[2] = '/nfs/users/nfs_f/fsk/1_cvs/BioPerl-1.6.0';
 
 #general perl modules
-$libs[3] = '/full-path/modules';
+$libs[3] = '/nfs/users/nfs_f/fsk/4_modules';
 
-#Otter modules for HAVANA db access
-# $libs[4] = '/full-path/ensembl-otter/modules';
-# $libs[5] = '/full-path/ensembl-variation/modules';
+#Otter mocdules for HAVANA db access
+$libs[4] = '/software/anacode/otter/otter_production_main/ensembl-otter/modules';
+$libs[5] = '/nfs/users/nfs_f/fsk/1_cvs/ensembl-variation/modules';
 
 ########## commands #####################
 
@@ -66,4 +65,3 @@ sub exec_cmd{
 
 ############################################
 
-
